@@ -16,7 +16,7 @@ from .text import *
 __package_name__ = 'pyhelpers'
 __package_name_alt__ = 'PyHelpers'
 __author__ = u'Qian Fu'
-__version__ = '1.2.6'
+__version__ = '1.2.9'
 __email__ = 'qian.fu@outlook.com'
-__description__ = \
-    'A handy toolkit for facilitating Python users\' data manipulation tasks.'
+__description__ = 'An open-source toolkit designed as a miscellaneous collection of simple ' \
+                  'but useful Python tools for facilitating data manipulation tasks.'
