@@ -4,34 +4,40 @@ Miscellaneous operations.
 
 import collections.abc
 import datetime
+import inspect
 import itertools
 import math
 import os
+import random
 import re
+import socket
 import time
 import types
+import urllib.parse
 
+import fake_useragent
 import numpy as np
 import pandas as pd
+import requests
+import tqdm
 
-""" General use -------------------------------------------------------------------- """
+""" General use ------------------------------------------------------------------------- """
 
 
-def confirmed(prompt=None, resp=False, confirmation_required=True):
+def confirmed(prompt=None, confirmation_required=True, resp=False):
     """
     Type to confirm whether to proceed or not.
 
-    See also
-    [`C-1 <http://sensitivecities.com/
-    so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
+    See also [`OPS-C-1
+    <https://code.activestate.com/recipes/541096-prompt-the-user-for-confirmation/>`_].
 
     :param prompt: a message that prompts an response (Yes/No), defaults to ``None``
     :type prompt: str or None
-    :param resp: default response, defaults to ``False``
-    :type resp: bool
     :param confirmation_required: whether to require users to confirm and proceed,
         defaults to ``True``
     :type confirmation_required: bool
+    :param resp: default response, defaults to ``False``
+    :type resp: bool
     :return: a response
     :rtype: bool
 
@@ -40,9 +46,9 @@ def confirmed(prompt=None, resp=False, confirmation_required=True):
         >>> from pyhelpers.ops import confirmed
 
         >>> if confirmed(prompt="Create Directory?", resp=True):
-        ...     print(True)
+        ...     print("Passed.")
         Create Directory? [No]|Yes: yes
-        True
+        Passed.
     """
 
     if confirmation_required:
@@ -67,7 +73,49 @@ def confirmed(prompt=None, resp=False, confirmation_required=True):
         return True
 
 
-""" Basic data manipulation -------------------------------------------------------- """
+def get_obj_attr(obj, col_names=None):
+    """
+    Get main attributes of an object.
+
+    :param obj: a object, e.g. a class
+    :type obj: object
+    :param col_names: a list of column names
+    :type col_names: list
+    :return: tabular data of the main attributes of the given object
+    :rtype: pandas.DataFrame
+
+    **Test**::
+
+        >>> from pyhelpers import get_obj_attr, PostgreSQL
+
+        >>> postgres = PostgreSQL(host='localhost', port=5432, username='postgres',
+        ...                       database_name='postgres')
+        Password (postgres@localhost:5432): ***
+        Connecting postgres:***@localhost:5432/postgres ... Successfully.
+
+        >>> obj_attr = get_obj_attr(postgres)
+        >>> print(obj_attr.head())
+               Attribute                                              Value
+        0        address               postgres:***@localhost:5432/postgres
+        1        backend                                         postgresql
+        2     connection  <sqlalchemy.pool.base._ConnectionFairy object ...
+        3  database_info  {'drivername': 'postgresql+psycopg2', 'host': ...
+        4  database_name                                           postgres
+    """
+
+    if col_names is None:
+        col_names = ['Attribute', 'Value']
+
+    all_attrs = inspect.getmembers(obj, lambda x: not (inspect.isroutine(x)))
+
+    attrs = [x for x in all_attrs if not re.match(r'^__?', x[0])]
+
+    attrs_tbl = pd.DataFrame(attrs, columns=col_names)
+
+    return attrs_tbl
+
+
+""" Basic data manipulation ------------------------------------------------------------- """
 
 
 # Iterable
@@ -76,7 +124,7 @@ def split_list_by_size(lst, sub_len):
     """
     Split a list into (evenly sized) sub-lists.
 
-    See also [`SLBS-1 <https://stackoverflow.com/questions/312443/>`_].
+    See also [`OPS-SLBS-1 <https://stackoverflow.com/questions/312443/>`_].
 
     :param lst: a list of any
     :type lst: list
@@ -105,7 +153,7 @@ def split_list(lst, num_of_sub):
     """
     Split a list into a number of equally-sized sub-lists.
 
-    See also [`SL-1 <https://stackoverflow.com/questions/312443/>`_].
+    See also [`OPS-SL-1 <https://stackoverflow.com/questions/312443/>`_].
 
     :param lst: a list of any
     :type lst: list
@@ -135,7 +183,7 @@ def split_iterable(iterable, chunk_size):
     """
     Split a list into (evenly sized) chunks.
 
-    See also [`SI-1 <https://stackoverflow.com/questions/24527006/>`_].
+    See also [`OPS-SI-1 <https://stackoverflow.com/questions/24527006/>`_].
 
     :param iterable: iterable object
     :type iterable: list or tuple or collections.abc.Iterable
@@ -146,7 +194,7 @@ def split_iterable(iterable, chunk_size):
 
     **Examples**::
 
-        >>> import pandas as pd_
+        >>> import pandas
         >>> from pyhelpers.ops import split_iterable
 
         >>> lst = list(range(0, 10))
@@ -159,7 +207,7 @@ def split_iterable(iterable, chunk_size):
         [6, 7, 8]
         [9]
 
-        >>> lst = pd_.Series(range(0, 20))
+        >>> lst = pandas.Series(range(0, 20))
         >>> size_of_chunk = 5
         >>> for lst_ in split_iterable(lst, size_of_chunk):
         ...     print(list(lst_))
@@ -178,7 +226,7 @@ def update_nested_dict(source_dict, updates):
     """
     Update a nested dictionary or similar mapping.
 
-    See also [`UND-1 <https://stackoverflow.com/questions/3232943/>`_].
+    See also [`OPS-UND-1 <https://stackoverflow.com/questions/3232943/>`_].
 
     :param source_dict: a dictionary that needs to be updated
     :type source_dict: dict
@@ -240,8 +288,8 @@ def get_all_values_from_nested_dict(key, target_dict):
     Get all values in a nested dictionary.
 
     See also
-    [`GAVFND-1 <https://gist.github.com/douglasmiranda/5127251>`_] and
-    [`GAVFND-2 <https://stackoverflow.com/questions/9807634/>`_].
+    [`OPS-GAVFND-1 <https://gist.github.com/douglasmiranda/5127251>`_] and
+    [`OPS-GAVFND-2 <https://stackoverflow.com/questions/9807634/>`_].
 
     :param key: any that can be the key of a dictionary
     :type key: any
@@ -319,6 +367,35 @@ def remove_multiple_keys_from_dict(target_dict, *keys):
             target_dict.pop(k)
 
 
+def merge_dicts(*dicts):
+    """
+    Merge multiple dictionaries.
+
+    :param dicts: (one or) multiple dictionaries
+    :type dicts: dict
+    :return: a single dictionary containing all elements of the input
+    :rtype: dict
+
+    **Example**::
+
+        >>> from pyhelpers.ops import merge_dicts
+
+        >>> dict_a = {'a': 1}
+        >>> dict_b = {'b': 2}
+        >>> dict_c = {'c': 3}
+
+        >>> merged_dict = merge_dicts(dict_a, dict_b, dict_c)
+        >>> print(merged_dict)
+        {'a': 1, 'b': 2, 'c': 3}
+    """
+
+    super_dict = {}
+    for d in dicts:
+        super_dict.update(d)
+
+    return super_dict
+
+
 # Tabular data
 
 def detect_nan_for_str_column(data_frame, column_names=None):
@@ -334,12 +411,12 @@ def detect_nan_for_str_column(data_frame, column_names=None):
 
     **Example**::
 
-        >>> import numpy as np_
-        >>> import pandas as pd_
+        >>> import numpy
+        >>> import pandas
         >>> from pyhelpers.ops import detect_nan_for_str_column
 
-        >>> df = pd_.DataFrame(np_.resize(range(10), (10, 2)), columns=['a', 'b'])
-        >>> df.iloc[3, 1] = np.nan
+        >>> df = pandas.DataFrame(numpy.resize(range(10), (10, 2)), columns=['a', 'b'])
+        >>> df.iloc[3, 1] = numpy.nan
 
         >>> nan_col_pos = detect_nan_for_str_column(df, column_names=None)
         >>> print(list(nan_col_pos))
@@ -350,8 +427,7 @@ def detect_nan_for_str_column(data_frame, column_names=None):
         column_names = data_frame.columns
 
     for x in column_names:
-        temp = [str(v) for v in data_frame[x].unique() if isinstance(v, str)
-                or np.isnan(v)]
+        temp = [str(v) for v in data_frame[x].unique() if isinstance(v, str) or np.isnan(v)]
         if 'nan' in temp:
             yield data_frame.columns.get_loc(x)
 
@@ -371,9 +447,9 @@ def create_rotation_matrix(theta):
 
         >>> rot_mat = create_rotation_matrix(theta=30)
 
-        >>> print(rotation_mat)
-        # [[-0.98803162  0.15425145]
-        #  [-0.15425145 -0.98803162]]
+        >>> print(rot_mat)
+        [[-0.98803162  0.15425145]
+         [-0.15425145 -0.98803162]]
     """
 
     sin_theta, cos_theta = np.sin(theta), np.cos(theta)
@@ -405,9 +481,9 @@ def dict_to_dataframe(input_dict, k='key', v='value'):
         >>> df = dict_to_dataframe(input_dict_)
 
         >>> print(df)
-        #   key  value
-        # 0   a      1
-        # 1   b      2
+          key  value
+        0   a      1
+        1   b      2
     """
 
     dict_keys = list(input_dict.keys())
@@ -424,30 +500,30 @@ def parse_csr_matrix(path_to_csr, verbose=False, **kwargs):
 
     :param path_to_csr: path where a CSR (e.g. .npz) file is saved
     :type path_to_csr: str
-    :param verbose: whether to print relevant information in console
-        as the function runs, defaults to ``False``
+    :param verbose: whether to print relevant information in console as the function runs,
+        defaults to ``False``
     :type verbose: bool or int
-    :param kwargs: optional parameters of
+    :param kwargs: optional arguments of
         `numpy.load <https://numpy.org/doc/stable/reference/generated/numpy.load>`_
     :return: a compressed sparse row
     :rtype: scipy.sparse.csr.csr_matrix
 
     **Example**::
 
-        >>> import numpy as np_
+        >>> import numpy
         >>> import scipy.sparse
         >>> from pyhelpers.dir import cd
         >>> from pyhelpers.ops import parse_csr_matrix
 
-        >>> data_ = np_.array([1, 2, 3, 4, 5, 6])
-        >>> indices_ = np_.array([0, 2, 2, 0, 1, 2])
-        >>> indptr_ = np_.array([0, 2, 3, 6])
+        >>> data_ = numpy.array([1, 2, 3, 4, 5, 6])
+        >>> indices_ = numpy.array([0, 2, 2, 0, 1, 2])
+        >>> indptr_ = numpy.array([0, 2, 3, 6])
         >>> csr_m = scipy.sparse.csr_matrix((data_, indices_, indptr_), shape=(3, 3))
 
         >>> path_to_csr_npz = cd("tests\\data", "csr_mat.npz")
-        >>> np_.savez_compressed(path_to_csr_npz, indptr=csr_m.indptr,
-        ...                      indices=csr_m.indices, data=csr_m.data,
-        ...                      shape=csr_m.shape)
+        >>> numpy.savez_compressed(path_to_csr_npz, indptr=csr_m.indptr,
+        ...                        indices=csr_m.indices, data=csr_m.data,
+        ...                        shape=csr_m.shape)
 
         >>> csr_mat_ = parse_csr_matrix(path_to_csr_npz, verbose=True)
         Loading "\\tests\\data\\csr_mat.npz" ... Done.
@@ -461,8 +537,7 @@ def parse_csr_matrix(path_to_csr, verbose=False, **kwargs):
     """
 
     if verbose:
-        print("Loading \"\\{}\"".format(os.path.relpath(path_to_csr)),
-              end=" ... ")
+        print("Loading \"\\{}\"".format(os.path.relpath(path_to_csr)), end=" ... ")
 
     try:
         csr_loader = np.load(path_to_csr, **kwargs)
@@ -482,7 +557,7 @@ def parse_csr_matrix(path_to_csr, verbose=False, **kwargs):
         print("Failed. {}".format(e)) if verbose else ""
 
 
-""" Basic computation -------------------------------------------------------------- """
+""" Basic computation ------------------------------------------------------------------- """
 
 
 def get_extreme_outlier_bounds(num_dat, k=1.5):
@@ -498,10 +573,10 @@ def get_extreme_outlier_bounds(num_dat, k=1.5):
 
     **Example**::
 
-        >>> import pandas as pd_
+        >>> import pandas
         >>> from pyhelpers.ops import get_extreme_outlier_bounds
 
-        >>> data = pd_.DataFrame(range(100), columns=['col'])
+        >>> data = pandas.DataFrame(range(100), columns=['col'])
 
         >>> lo_bound, up_bound = get_extreme_outlier_bounds(data, k=1.5)
 
@@ -522,8 +597,7 @@ def interquartile_range(num_dat):
     """
     Calculate interquartile range.
 
-    This function may be an alternative to
-    `scipy.stats.iqr
+    This function may be an alternative to `scipy.stats.iqr
     <https://docs.scipy.org/doc/scipy/reference/generated/scipy.stats.iqr.html>`_.
 
     :param num_dat: an array of numbers
@@ -533,10 +607,10 @@ def interquartile_range(num_dat):
 
     **Example**::
 
-        >>> import pandas as pd_
+        >>> import pandas
         >>> from pyhelpers.ops import interquartile_range
 
-        >>> data = pd_.DataFrame(range(100), columns=['col'])
+        >>> data = pandas.DataFrame(range(100), columns=['col'])
 
         >>> iqr_ = interquartile_range(data)
         >>> print(iqr_)
@@ -566,24 +640,23 @@ def find_closest_date(date, lookup_dates, as_datetime=False, fmt='%Y-%m-%d %H:%M
 
     **Examples**::
 
-        >>> import pandas as pd_
+        >>> import pandas
         >>> from pyhelpers.ops import find_closest_date
 
-        >>> date_list = pd_.date_range('2019-01-02', '2019-12-31')
+        >>> date_list = pandas.date_range('2019-01-02', '2019-12-31')
 
         >>> date_ = '2019-01-01'
         >>> closest_date_ = find_closest_date(date_, date_list, as_datetime=True)
         >>> print(closest_date_)  # Timestamp('2019-01-02 00:00:00', freq='D')
         2019-01-02 00:00:00
 
-        >>> date_ = pd_.to_datetime('2019-01-01')
+        >>> date_ = pandas.to_datetime('2019-01-01')
         >>> closest_date_ = find_closest_date(date_, date_list, as_datetime=False)
         >>> print(closest_date_)  # '2019-01-02 00:00:00.000000'
         2019-01-02 00:00:00.000000
     """
 
-    closest_date = min(lookup_dates,
-                       key=lambda x: abs(pd.to_datetime(x) - pd.to_datetime(date)))
+    closest_date = min(lookup_dates, key=lambda x: abs(pd.to_datetime(x) - pd.to_datetime(date)))
 
     if as_datetime:
         if isinstance(closest_date, str):
@@ -596,46 +669,54 @@ def find_closest_date(date, lookup_dates, as_datetime=False, fmt='%Y-%m-%d %H:%M
     return closest_date
 
 
-""" Graph plotting ----------------------------------------------------------------- """
+""" Graph plotting ---------------------------------------------------------------------- """
 
 
 def cmap_discretisation(cmap, n_colours):
     """
     Create a discrete colour ramp.
 
-    See also [`CD-1 <http://sensitivecities.com/
-    so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
+    See also [`OPS-CD-1
+    <http://sensitivecities.com/so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
 
-    :param cmap: a colormap instance,
-        such as built-in `colormaps`_ accessible via `matplotlib.cm.get_cmap`_
+    :param cmap: a colormap instance, such as built-in `colormaps`_ accessible
+        via `matplotlib.cm.get_cmap`_
     :type cmap: matplotlib.colors.ListedColormap
     :param n_colours: number of colours
     :type n_colours: int
     :return: a discrete colormap from (the continuous) ``cmap``
     :rtype: matplotlib.colors.LinearSegmentedColormap
 
-    .. _`colormaps`: https://matplotlib.org/tutorials/colors/colormaps.html
+    .. _`colormaps`:
+        https://matplotlib.org/tutorials/colors/colormaps.html
     .. _`matplotlib.cm.get_cmap`:
         https://matplotlib.org/api/cm_api.html#matplotlib.cm.get_cmap
 
     **Example**::
 
         >>> import matplotlib.cm
-        >>> import matplotlib.pyplot as plt_
-        >>> import numpy as np_
+        >>> import matplotlib.pyplot as plt
+        >>> import numpy
         >>> from pyhelpers.ops import cmap_discretisation
 
         >>> cm_accent = cmap_discretisation(matplotlib.cm.get_cmap('Accent'), n_colours=5)
 
-        >>> fig, ax = plt_.subplots(figsize=(10, 2))
-        >>> ax.imshow(np_.resize(range(100), (5, 100)), cmap=cm_accent,
+        >>> fig, ax = plt.subplots(figsize=(10, 2))
+        >>> ax.imshow(numpy.resize(range(100), (5, 100)), cmap=cm_accent,
         ...           interpolation='nearest')
-        >>> plt_.axis('off')
-        >>> plt_.tight_layout()
-        >>> plt_.show()
+        >>> plt.axis('off')
+        >>> plt.tight_layout()
+        >>> plt.show()
 
-    .. image:: ../_images/cmap-discretisation.*
-       :width: 400pt
+    The exmaple is illustrated in :numref:`cmap-discretisation`:
+
+    .. figure:: ../_images/cmap-discretisation.*
+        :name: cmap-discretisation
+        :align: center
+        :width: 60%
+
+        An example of discrete colour ramp, created by
+        :py:func:`cmap_discretisation()<pyhelpers.ops.cmap_discretisation>`.
     """
 
     if isinstance(cmap, str):
@@ -665,21 +746,22 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
     To stop making off-by-one errors. Takes a standard colour ramp, and discretizes it,
     then draws a colour bar with correctly aligned labels.
 
-    See also [`CBI-1 <http://sensitivecities.com/
-    so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
+    See also [`OPS-CBI-1
+    <http://sensitivecities.com/so-youd-like-to-make-a-map-using-python-EN.html#.WbpP0T6GNQB>`_].
 
-    :param cmap: a colormap instance,
-        such as built-in `colormaps`_ accessible via `matplotlib.cm.get_cmap`_
+    :param cmap: a colormap instance, such as built-in `colormaps`_ accessible
+        via `matplotlib.cm.get_cmap`_
     :type cmap: matplotlib.colors.ListedColormap
     :param n_colours: number of colours
     :type n_colours: int
     :param labels: a list of labels for the colour bar, defaults to ``None``
     :type labels: list or None
-    :param kwargs: optional parameters of `matplotlib.pyplot.colorbar`_
+    :param kwargs: optional arguments of `matplotlib.pyplot.colorbar`_
     :return: a colour bar object
     :rtype: matplotlib.colorbar.Colorbar
 
-    .. _`colormaps`: https://matplotlib.org/tutorials/colors/colormaps.html
+    .. _`colormaps`:
+        https://matplotlib.org/tutorials/colors/colormaps.html
     .. _`matplotlib.cm.get_cmap`:
         https://matplotlib.org/api/cm_api.html#matplotlib.cm.get_cmap
     .. _`matplotlib.pyplot.colorbar`:
@@ -688,31 +770,43 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
     **Examples**::
 
         >>> import matplotlib.cm
-        >>> import matplotlib.pyplot as plt_
+        >>> import matplotlib.pyplot as plt
         >>> from pyhelpers.ops import colour_bar_index
 
-        >>> plt_.figure(figsize=(2, 6))
+        >>> plt.figure(figsize=(2, 6))
         >>> cbar = colour_bar_index(cmap=matplotlib.cm.get_cmap('Accent'), n_colours=5)
         >>> cbar.ax.tick_params(labelsize=18)
-        >>> plt_.axis('off')
-        >>> plt_.tight_layout()
-        >>> plt_.show()
+        >>> plt.axis('off')
+        >>> plt.tight_layout()
+        >>> plt.show()
 
-    .. image:: ../_images/colour-bar-index-1.*
-        :width: 120pt
+    The above example is illustrated in :numref:`colour-bar-index-1`:
+
+    .. figure:: ../_images/colour-bar-index-1.*
+        :name: colour-bar-index-1
+        :width: 17%
+
+        An example of colour bar with numerical index, created by
+        :py:func:`colour_bar_index()<pyhelpers.ops.colour_bar_index>`.
 
     .. code-block:: python
 
-        >>> plt_.figure(figsize=(2, 6))
+        >>> plt.figure(figsize=(2, 6))
         >>> cbar = colour_bar_index(matplotlib.cm.get_cmap('Accent'), n_colours=5,
         ...                         labels=list('abcde'))
         >>> cbar.ax.tick_params(labelsize=18)
-        >>> plt_.axis('off')
-        >>> plt_.tight_layout()
-        >>> plt_.show()
+        >>> plt.axis('off')
+        >>> plt.tight_layout()
+        >>> plt.show()
 
-    .. image:: ../_images/colour-bar-index-2.*
-       :width: 120pt
+    This second example is illustrated in :numref:`colour-bar-index-2`:
+
+    .. figure:: ../_images/colour-bar-index-2.*
+        :name: colour-bar-index-2
+        :width: 17%
+
+        An example of colour bar with textual index, created by
+        :py:func:`colour_bar_index()<pyhelpers.ops.colour_bar_index>`.
     """
 
     cmap = cmap_discretisation(cmap, n_colours)
@@ -722,8 +816,8 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
     mappable.set_array(np.array([]))
     mappable.set_clim(-0.5, n_colours + 0.5)
 
-    import matplotlib.pyplot as plt
-    colour_bar = plt.colorbar(mappable, **kwargs)
+    import matplotlib.pyplot
+    colour_bar = matplotlib.pyplot.colorbar(mappable, **kwargs)
     colour_bar.set_ticks(np.linspace(0, n_colours, n_colours))
     colour_bar.set_ticklabels(range(n_colours))
 
@@ -733,17 +827,70 @@ def colour_bar_index(cmap, n_colours, labels=None, **kwargs):
     return colour_bar
 
 
-""" Web scraping ------------------------------------------------------------------- """
+""" Web scraping ------------------------------------------------------------------------ """
 
 
-def fake_requests_headers(random=False):
+def is_network_connected():
     """
-    Make a fake HTTP headers for
-    `requests.get <https://requests.readthedocs.io/en/master/user/
-    advanced/#request-and-response-objects>`_.
+    Check if the current machine can connect to the Internet.
 
-    :param random: whether to go for a random agent, defaults to ``False``
-    :type random: bool
+    :return: whether the Internet connection is currently working
+    :rtype: bool
+
+    **Examples**::
+
+        >>> from pyhelpers.ops import is_network_connected
+
+        >>> is_network_connected()
+        >>> # if the machine is currently connected to the Internet
+        True
+    """
+
+    host_name = socket.gethostname()
+    ip_address = socket.gethostbyname(host_name)
+
+    return False if ip_address == "127.0.0.1" else True
+
+
+def is_url_connectable(url):
+    """
+    Check if the current machine can connect to a given URL.
+
+    :param url: a URL
+    :type url: str
+    :return: whether the machine can currently connect to the given URL
+    :rtype: bool
+
+    **Examples**::
+
+        >>> from pyhelpers.ops import is_url_connectable
+
+        >>> url_0 = 'https://www.python.org/'
+        >>> is_url_connectable(url_0)
+        True
+
+        >>> url_1 = 'https://www.python.org1/'
+        >>> is_url_connectable(url_1)
+        False
+    """
+
+    try:
+        netloc = urllib.parse.urlparse(url).netloc
+        host = socket.gethostbyname(netloc)
+        s = socket.create_connection((host, 80))
+        s.close()
+        return True
+    except (socket.gaierror, OSError):
+        return False
+
+
+def fake_requests_headers(randomized=False):
+    """
+    Make a fake HTTP headers for `requests.get
+    <https://requests.readthedocs.io/en/master/user/advanced/#request-and-response-objects>`_.
+
+    :param randomized: whether to go for a random agent, defaults to ``False``
+    :type randomized: bool
     :return: fake HTTP headers
     :rtype: dict
 
@@ -756,7 +903,7 @@ def fake_requests_headers(random=False):
         {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 '
                        '(KHTML, like Gecko) Chrome/41.0.2227.0 Safari/537.36'}
 
-        >>> fake_headers_ = fake_requests_headers(random=True)
+        >>> fake_headers_ = fake_requests_headers(randomized=True)
         >>> print(fake_headers_)
         {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.36'
                        ' (KHTML, like Gecko) Chrome/36.0.1944.0 Safari/537.36'}
@@ -766,17 +913,14 @@ def fake_requests_headers(random=False):
         The above ``fake_headers_`` may be different every time we run the examples.
     """
 
-    import fake_useragent
-
     try:
         fake_user_agent = fake_useragent.UserAgent(verify_ssl=False)
-        ua = fake_user_agent.random if random else fake_user_agent['google chrome']
+        ua = fake_user_agent.random if randomized else fake_user_agent['google chrome']
 
     except fake_useragent.FakeUserAgentError:
         fake_user_agent = fake_useragent.UserAgent(verify_ssl=False)
 
-        if random:
-            import random
+        if randomized:
             ua = random.choice(fake_user_agent.data_browsers['internetexplorer'])
         else:
             ua = fake_user_agent['Internet Explorer']
@@ -789,20 +933,19 @@ def fake_requests_headers(random=False):
 def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=False,
                            **kwargs):
     """
-    Download an object available at the given ``url``.
+    Download an object available at a given URL.
 
-    See also [`DFFU-1 <https://stackoverflow.com/questions/37573483/>`_].
+    See also [`OPS-DFFU-1 <https://stackoverflow.com/questions/37573483/>`_].
 
-    :param url: URL
+    :param url: a URL
     :type url: str
     :param path_to_file: a full path to which the downloaded object is saved as
     :type path_to_file: str
-    :param wait_to_retry: a wait time to retry downloading,
-        defaults to ``3600`` (in second)
+    :param wait_to_retry: a wait time to retry downloading, defaults to ``3600`` (in second)
     :type wait_to_retry: int or float
     :param random_header: whether to go for a random agent, defaults to ``False``
     :type random_header: bool
-    :param kwargs: optional parameters of
+    :param kwargs: optional arguments of
         `open <https://docs.python.org/3/library/functions.html#open>`_
 
     **Example**::
@@ -810,18 +953,12 @@ def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=
         >>> from pyhelpers.dir import cd
         >>> from pyhelpers.ops import download_file_from_url
 
-        >>> url_to_python_logo = 'https://www.python.org/static/community_logos/' \
-        ...                      'python-logo-master-v3-TM.png'
+        >>> logo_url = 'https://www.python.org/static/community_logos/python-logo-master-v3-TM.png'
 
-        >>> img_dir = cd("tests\\images")
-        >>> path_to_python_logo_png = cd(img_dir, "python-logo.png")
-
-        >>> download_file_from_url(url_to_python_logo, path_to_python_logo_png)
+        >>> download_file_from_url(logo_url, cd("tests\\images", "python-logo.png"))
     """
 
-    import requests
-
-    headers = fake_requests_headers(random_header)
+    headers = fake_requests_headers(randomized=random_header)
     # Streaming, so we can iterate over the response
     resp = requests.get(url, stream=True, headers=headers)
 
@@ -839,8 +976,6 @@ def download_file_from_url(url, path_to_file, wait_to_retry=3600, random_header=
         if not os.path.exists(directory):
             os.makedirs(directory)
 
-    import tqdm
-
     with open(path_to_file, mode='wb', **kwargs) as f:
         for data in tqdm.tqdm(resp.iter_content(block_size, decode_unicode=True),
                               total=total_size // block_size, unit='MB'):
