@@ -9,13 +9,14 @@ import re
 import string
 import subprocess
 
+import fuzzywuzzy.fuzz
 import numpy as np
 import pandas as pd
 
 from .ops import dict_to_dataframe
 from .store import get_specific_filepath_info
 
-""" Basic processing of textual data ----------------------------------------------- """
+""" Basic processing of textual data ---------------------------------------------------- """
 
 
 def remove_punctuation(raw_txt, rm_whitespace=False):
@@ -58,7 +59,92 @@ def remove_punctuation(raw_txt, rm_whitespace=False):
     return txt
 
 
-""" Comparison of textual data ----------------------------------------------------- """
+def get_acronym(text, only_capitals=False, capitals_in_words=False):
+    """
+    Get an acronym (in capital letters) of an input text.
+
+    :param text: any text
+    :type text: str
+    :param only_capitals: whether to include capital letters only, defaults to ``False``
+    :type only_capitals: bool
+    :param capitals_in_words: whether to include all captical letters in a single word,
+        defaults to ``False``
+    :type capitals_in_words: bool
+    :return: acronym of the input ``str_var``
+    :rtype: str
+
+    **Examples**::
+
+        >>> from pyhelpers.text import get_acronym
+
+        >>> text_a = 'This is an apple.'
+        >>> acron = get_acronym(text_a)
+        >>> print(acron)
+        TIAA
+
+        >>> text_b = "I'm at the University of Birmingham."
+        >>> acron =get_acronym(text_b, only_capitals=True)
+        >>> print(acron)
+        IUB
+
+        >>> text_c = 'There is a "ConnectionError"!'
+        >>> acron = get_acronym(text_c, capitals_in_words=True)
+        >>> print(acron)
+        TCE
+    """
+
+    txt = remove_punctuation(text)
+
+    if only_capitals:
+        acronym = ''.join(x[0] for x in txt.split() if x[0].isupper())
+    elif capitals_in_words:
+        acronym = ''.join(list(filter(str.isupper, txt)))
+    else:
+        acronym = ''.join(x[0].upper() for x in txt.split())
+
+    return acronym
+
+
+def extract_words1upper(x, join_with=None):
+    """
+    Extract words from a string by spliting it at occurrence of an uppercase letter.
+
+    :param x: a string joined by a number of words each starting with an uppercase letter
+    :type x: str
+    :param join_with: a string with which to (re)join the single words,
+        defaults to ``None``
+    :type join_with: str or None
+    :return: a list of single words each starting with an uppercase letter,
+        or a single string joined together by them with ``join_with``
+    :rtype: list or str
+
+    **Examples**::
+
+        >>> from pyhelpers.text import extract_words1upper
+
+        >>> x1 = 'NetworkWaymarks'
+        >>> res = extract_words1upper(x1, join_with=' ')
+        >>> print(res)
+        Network Waymarks
+
+        >>> x2 = 'Retaining_Wall'
+        >>> res = extract_words1upper(x2, join_with=' ')
+        >>> print(res)
+        Retaining Wall
+    """
+
+    x_ = remove_punctuation(x)
+
+    # re.sub(r"([A-Z])", r" \1", x).split()
+    extracted_words = re.findall(r'[a-zA-Z][^A-Z]*', x_)
+
+    if join_with:
+        extracted_words = join_with.join(extracted_words)
+
+    return extracted_words
+
+
+""" Comparison of textual data ---------------------------------------------------------- """
 
 
 def find_similar_str(str_x, lookup_list, processor='fuzzywuzzy', **kwargs):
@@ -82,7 +168,8 @@ def find_similar_str(str_x, lookup_list, processor='fuzzywuzzy', **kwargs):
     :return: a string-type variable that should be similar to (or the same as) ``str_x``
     :rtype: str
 
-    .. _`fuzzywuzzy.fuzz.token_set_ratio`: https://github.com/seatgeek/fuzzywuzzy
+    .. _`fuzzywuzzy.fuzz.token_set_ratio`:
+        https://github.com/seatgeek/fuzzywuzzy
     .. _`nltk.metrics.distance.edit_distance`:
         https://www.nltk.org/api/nltk.metrics.html#nltk.metrics.distance.edit_distance
 
@@ -97,13 +184,11 @@ def find_similar_str(str_x, lookup_list, processor='fuzzywuzzy', **kwargs):
         >>> print(str_similar)
         app
 
-        >>> str_similar = find_similar_str(x, lookup_lst, processor='nltk',
-        ...                                substitution_cost=1)
+        >>> str_similar = find_similar_str(x, lookup_lst, processor='nltk', substitution_cost=1)
         >>> print(str_similar)
         aapl
 
-        >>> str_similar = find_similar_str(x, lookup_list, processor='nltk',
-        ...                                substitution_cost=100)
+        >>> str_similar = find_similar_str(x, lookup_lst, 'nltk', substitution_cost=100)
         >>> print(str_similar)
         app
     """
@@ -112,7 +197,6 @@ def find_similar_str(str_x, lookup_list, processor='fuzzywuzzy', **kwargs):
         "`processor` must be either \"fuzzywuzzy\" or \"nltk\"."
 
     if processor == 'fuzzywuzzy':
-        import fuzzywuzzy.fuzz
 
         l_distances = [fuzzywuzzy.fuzz.token_set_ratio(str_x, a, **kwargs)
                        for a in lookup_list]
@@ -151,24 +235,23 @@ def find_matched_str(str_x, lookup_list):
 
     **Examples**::
 
-        from pyhelpers.text import find_matched_str
+        >>> from pyhelpers.text import find_matched_str
 
-        x = 'apple'
+        >>> x = 'apple'
 
-        lookup_list = ['abc', 'aapl', 'app', 'ap', 'ape', 'apex', 'apel']
-        res = find_matched_str(x, lookup_list)
-        print(list(res))
-        # []
+        >>> lookup_lst = ['abc', 'aapl', 'app', 'ap', 'ape', 'apex', 'apel']
+        >>> res = find_matched_str(x, lookup_lst)
+        >>> print(list(res))
+        []
 
-        lookup_list = ['abc', 'aapl', 'app', 'apple', 'ape', 'apex', 'apel']
-        res = find_matched_str(x, lookup_list)
-        print(list(res))
-        # ['apple']
+        >>> lookup_lst = ['abc', 'aapl', 'app', 'apple', 'ape', 'apex', 'apel']
+        >>> res = find_matched_str(x, lookup_lst)
+        >>> print(list(res))
+        ['apple']
     """
 
     assert isinstance(str_x, str), "`x` must be a string."
-    assert isinstance(lookup_list, collections.abc.Iterable), \
-        "`lookup_list` must be iterable."
+    assert isinstance(lookup_list, collections.abc.Iterable), "`lookup_list` must be iterable."
 
     if str_x == '' or str_x is None:
         return None
@@ -179,7 +262,7 @@ def find_matched_str(str_x, lookup_list):
                 yield y
 
 
-""" Basic computation of textual data ---------------------------------------------- """
+""" Basic computation of textual data --------------------------------------------------- """
 
 
 def count_words(raw_txt):
@@ -193,8 +276,7 @@ def count_words(raw_txt):
 
     **Examples**::
 
-        >>> from pyhelpers.text import count_words
-        >>> from pyhelpers.text import remove_punctuation
+        >>> from pyhelpers.text import count_words, remove_punctuation
 
         >>> raw_text = 'This is an apple. That is a pear. Hello world!'
 
@@ -247,13 +329,13 @@ def calculate_idf(raw_documents, rm_punc=False):
 
     **Examples**::
 
-        >>> import pandas as pd_
+        >>> import pandas
         >>> from pyhelpers.text import calculate_idf
 
-        >>> raw_doc = pd_.Series(['This is an apple.',
-        ...                       'That is a pear.',
-        ...                       'It is human being.',
-        ...                       'Hello world!'])
+        >>> raw_doc = pandas.Series(['This is an apple.',
+        ...                          'That is a pear.',
+        ...                          'It is human being.',
+        ...                          'Hello world!'])
 
         >>> docs_tf_, corpus_idf_ = calculate_idf(raw_doc, rm_punc=False)
         >>> print(docs_tf_)
@@ -313,8 +395,7 @@ def calculate_idf(raw_documents, rm_punc=False):
 
     n = len(raw_docs)
     tokens = [w for tokens in tokens_in_docs for w in tokens]
-    tokens_counter = dict_to_dataframe(dict(collections.Counter(tokens)),
-                                       'token', 'count')
+    tokens_counter = dict_to_dataframe(dict(collections.Counter(tokens)), 'token', 'count')
     tokens_counter['idf'] = np.log(n / (1 + tokens_counter['count'].values))
 
     corpus_idf = dict(zip(tokens_counter['token'], tokens_counter['idf']))
@@ -328,21 +409,20 @@ def calculate_tf_idf(raw_documents, rm_punc=False):
 
     :param raw_documents: a series of documents
     :type raw_documents: pandas.Series
-    :param rm_punc: whether to remove punctuation from ``raw_documents``,
-        defaults to ``False``
+    :param rm_punc: whether to remove punctuation from ``raw_documents``, defaults to ``False``
     :type rm_punc: bool
     :return: tf-idf of the ``raw_documents``
     :rtype: dict
 
     **Examples**::
 
-        >>> import pandas as pd_
+        >>> import pandas
         >>> from pyhelpers.text import calculate_tf_idf
 
-        >>> raw_doc = pd_.Series(['This is an apple.',
-        ...                       'That is a pear.',
-        ...                       'It is human being.',
-        ...                       'Hello world!'])
+        >>> raw_doc = pandas.Series(['This is an apple.',
+        ...                          'That is a pear.',
+        ...                          'It is human being.',
+        ...                          'Hello world!'])
 
         >>> docs_tf_idf_ = calculate_tf_idf(raw_doc, rm_punc=False)
         >>> print(docs_tf_idf_)
@@ -417,8 +497,8 @@ def cosine_similarity_between_texts(txt1, txt2, cosine_distance=False):
     :type txt1: str
     :param txt2: any text
     :type txt2: str
-    :param cosine_distance: whether to get cosine distance,
-        which is (1 - cosine similarity), defaults to ``False``
+    :param cosine_distance: whether to get cosine distance, which is (1 - cosine similarity),
+        defaults to ``False``
     :type cosine_distance: bool
     :return: cosine similarity (or distance)
     :rtype: float
@@ -453,8 +533,7 @@ def cosine_similarity_between_texts(txt1, txt2, cosine_distance=False):
     s1_count, s2_count = np.array(s1_count), np.array(s2_count)
 
     similarity = np.dot(s1_count, s2_count)
-    cos_similarity = np.divide(similarity,
-                               np.linalg.norm(s1_count) * np.linalg.norm(s2_count))
+    cos_similarity = np.divide(similarity, np.linalg.norm(s1_count) * np.linalg.norm(s2_count))
 
     if cosine_distance:
         cos_similarity = 1 - cos_similarity
@@ -462,7 +541,7 @@ def cosine_similarity_between_texts(txt1, txt2, cosine_distance=False):
     return cos_similarity
 
 
-""" Transformation of textual data ------------------------------------------------- """
+""" Transformation of textual data ------------------------------------------------------ """
 
 
 def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, **kwargs):
@@ -508,8 +587,7 @@ def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, *
     # assert abs_md_path.suffix == ".md" and abs_rst_path.suffix == ".rst"
 
     if verbose:
-        print("Converting \"{}\" to RST (.rst) file ... ".format(
-            abs_md_path.name))
+        print("Converting \"{}\" to RST (.rst) file ... ".format(abs_md_path.name))
         get_specific_filepath_info(abs_rst_path, verbose=verbose, verbose_end=" ... ")
 
     if pandoc_exe is None:
@@ -517,19 +595,19 @@ def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, *
 
     try:
         if os.path.isfile(pandoc_exe):
-            subprocess.call('"{}" "{}" -f markdown -t rst -s -o "{}"'.format(
-                pandoc_exe, abs_md_path, abs_rst_path))
+            subprocess.call(
+                '"{}" "{}" -f markdown -t rst -s -o "{}"'.format(
+                    pandoc_exe, abs_md_path, abs_rst_path))
         else:
-            subprocess.call('pandoc "{}" -f markdown -t rst -s -o "{}"'.format(
-                abs_md_path, abs_rst_path))
+            subprocess.call(
+                'pandoc "{}" -f markdown -t rst -s -o "{}"'.format(abs_md_path, abs_rst_path))
 
         print("Done.") if verbose else ""
 
     except FileNotFoundError:
         import pypandoc
 
-        pypandoc.convert_file(str(abs_md_path), 'rst',
-                              outputfile=str(abs_rst_path), **kwargs)
+        pypandoc.convert_file(str(abs_md_path), 'rst', outputfile=str(abs_rst_path), **kwargs)
         print("Done.") if verbose else ""
 
     except Exception as e:
